package THEMA::MEDIA;

our $VERSION = 2014.1002_001;



                                        
                    ########            
                    ########            
                    ########  ########  
          ########  ########  ########  
          ########            ########  
          ########  ########  ########  
          ########  ########            
                    ########  ########  
          ########  ########  ########  
          ########            ########  
          ########  ########  ########  
          ########  ########            
                    ########            
                    ########            (c) 1994  www.THEMA-MEDIA.nl
                                        





print <<BANNER_END;

             _______             
            |       |            
            |       |  _______   
   _______  |       | |       |  
  |       | |_______| |       |  
  |       |  _______  |       |  
  |       | |       | |_______|  
  |_______| |       |  _______   
   _______  |       | |       |  
  |       | |_______| |       |  
  |       |  _______  |       |  
  |       | |       | |_______|  
  |_______| |       |            
            |       |            
            |_______|            
                                 
  (c) 1994 - 2014   THEMA-MEDIA  
                                 
BANNER_END

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

THEMA::MEDIA

=head1 VERSION

version 2014.10.02

=head1 SYNOPSIS

  #! /usr/bin/env perl
  
  use strict;
  use warnings;
  
  use v5.20.1;
  use feature "signatures";
  
  use THEMA::MEDIA;

=head1 DESCRIPTION

... I will come up with a proper description

=head1 NAME

THEMA-MEDIA - Providing solutions with Modern Perl

=head1 ABSTRACT

Much has changed in twenty years...
But THEMA-MEDIA still provides solutions based on proven technologies

=head1 EXPORT

none, there is no code yet

=head1 AUTHOR

Theo van Hoesel, <Th.J.v.Hoesel@THEMA-MEDIA.nl>

=head1 COPYRIGHT AND LICENSE

(c) 2014 by THEMA-MEDIA, Th. J. van Hoesel

This library is free software; you can redistribute it and/or modify
it under the same licence as Perl itself.

=head1 AUTHOR

Theo van Hoesel <Th.J.v.Hoesel@THEMA-MEDIA.nl>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by THEMA-MEDIA, Th. J. van  Hoesel.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
